%define anolis_release 4

%bcond_without asm
%bcond_without lz4
%bcond_without lzma
%bcond_without zlib
%ifarch x86_64
%bcond_without pzstd
%else
%bcond_with pzstd
%endif

Name:           zstd
Version:        1.5.2
Release:        %{anolis_release}%{?dist}
Summary:        Zstd compression library

License:        BSD and GPLv2
URL:            https://github.com/facebook/zstd
Source0:        https://github.com/facebook/zstd/releases/download/v%{version}/%{name}-%{version}.tar.zst

Patch1:         pzstd.1.patch
Patch2:         enable-CET.patch
# https://github.com/facebook/zstd/commit/4021b784376c3790c077e9b8deedbb6a4f016687
Patch3:         fix-for-error-message-in-recursive-mode-for-an-empty.patch
# https://github.com/facebook/zstd/commit/246982e782849d8646b2d5df6648319935669228
Patch4:         dibio-Fix-assertion-triggered-by-no-inputs.patch
# https://github.com/facebook/zstd/commit/470eb8330a9821c334df7efe66945a63d1faf017
Patch5:         Fix-required-decompression-memory-usage-reported-by-.patch
# https://github.com/facebook/zstd/commit/d109cef2012b1e0ca7a6f47278a2838f68bbc196
Patch6:         fix-the-assertion-in-readLinesFromFile-3084.patch
# https://github.com/facebook/zstd/commit/e1873ad576cb478fff0e6e44ad99599cd5fd2846
Patch7:         Fix-buffer-underflow-for-null-dir1.patch
# https://github.com/facebook/zstd/commit/ae4670466c5db56493f356c1a81e8cbefef3271e
Patch8:         stdin-multiple-file-fixes-3222.patch
# https://github.com/facebook/zstd/commit/b7d55cfa0d0942c2cb74d47076847c401653f9ed
Patch9:         fix-issue-3119.patch
# https://github.com/facebook/zstd/commit/361d86998ad877a678c5ffead30ecaf0c815c9aa
Patch10:        Fix-the-wrong-check-for-buffer-overrun-in-UTIL_merge.patch
# https://github.com/facebook/zstd/commit/f31b83ff34236b4c8ec7dc5332c52a7e67952215
Patch11:        Fix-nullptr-addition-improve-fuzzer.patch

BuildRequires:  make cmake 
BuildRequires:  gcc gtest-devel
%if %{with lz4}
BuildRequires:  lz4-devel
%endif
%if %{with lzma}
BuildRequires:  xz-devel
%endif
%if %{with pzstd}
BuildRequires:  gcc-c++
%endif
%if %{with zlib}
BuildRequires:  zlib-devel
%endif
BuildRequires:  execstack

%description
Zstd, short for Zstandard, is a fast lossless compression algorithm,
targeting real-time compression scenarios at zlib-level compression ratio.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package -n	lib%{name}
Summary:        Zstd shared library

%description -n lib%{name}
Zstandard compression shared library.

%package -n	lib%{name}-devel
Summary:        Header files for Zstd library
Requires:       lib%{name} = %{version}-%{release}

%package -n	lib%{name}-static
Summary:        Static variant of the Zstd library
Requires:       lib%{name}-devel = %{version}-%{release}

%description -n lib%{name}-devel
Header files for Zstd library.

%description -n lib%{name}-static
Static variant of the Zstd library.

%prep
%setup -q
find -name .gitignore -delete
%if %{with pzstd}
%patch1 -p1
%endif
%autopatch -p1 -m 2

%build
export CFLAGS="$RPM_OPT_FLAGS"
export LDFLAGS="$RPM_LD_FLAGS"
export PREFIX="%{_prefix}"
export LIBDIR="%{_libdir}"
%make_build -C lib lib-mt %{!?with_asm:ZSTD_NO_ASM=1}
%make_build -C programs %{!?with_asm:ZSTD_NO_ASM=1}
%if %{with pzstd}
export CXXFLAGS="$RPM_OPT_FLAGS"
%make_build -C contrib/pzstd %{!?with_asm:ZSTD_NO_ASM=1}
%endif

cd build/cmake
mkdir builddir
cd builddir
cmake ..
make

%install
%make_install PREFIX=%{_prefix} LIBDIR=%{_libdir}
%if %{with pzstd}
install -D -m755 contrib/pzstd/pzstd %{buildroot}%{_bindir}/pzstd
install -D -m644 programs/%{name}.1 %{buildroot}%{_mandir}/man1/p%{name}.1
%endif

pushd build/cmake/builddir
mkdir cmake_install_dir
make install DESTDIR=./cmake_install_dir
mkdir -p %{buildroot}/%{_libdir}/cmake/zstd
cp -r cmake_install_dir/usr/local/lib64/cmake/zstd/*.cmake %{buildroot}/%{_libdir}/cmake/zstd/
popd

%generate_compatibility_deps

%check
execstack lib/libzstd.so.1
export CFLAGS="$RPM_OPT_FLAGS"
export LDFLAGS="$RPM_LD_FLAGS"
make -C tests test-zstd
%if %{with pzstd}
export CXXFLAGS="$RPM_OPT_FLAGS"
make -C contrib/pzstd test
%endif


%files
%license COPYING LICENSE
%{_bindir}/%{name}
%if %{with pzstd}
%{_bindir}/p%{name}
%{_mandir}/man1/p%{name}.1*
%{abidir}/p%{name}-option.list
%endif
%{abidir}/%{name}*-option.list
%{_bindir}/%{name}mt
%{_bindir}/un%{name}
%{_bindir}/%{name}cat
%{_bindir}/%{name}grep
%{_bindir}/%{name}less
%{_mandir}/man1/%{name}.1*
%{_mandir}/man1/un%{name}.1*
%{_mandir}/man1/%{name}cat.1*
%{_mandir}/man1/%{name}grep.1*
%{_mandir}/man1/%{name}less.1*

%files doc
%doc CHANGELOG README.md

%files -n lib%{name}
%license COPYING LICENSE
%dir %{abidir}
%{_libdir}/libzstd.so.*
%{abidir}/libzstd.dump

%files -n lib%{name}-devel
%{_includedir}/zdict.h
%{_includedir}/zstd.h
%{_includedir}/zstd_errors.h
%{_libdir}/pkgconfig/libzstd.pc
%{_libdir}/libzstd.so
%{_libdir}/cmake/zstd/

%files -n lib%{name}-static
%{_libdir}/libzstd.a

%ldconfig_scriptlets -n lib%{name}

%changelog
* Sun Jan 08 2023 Shawn Wang <shawnwang@linux.alibaba.com> - 1.5.2-4
- add some patches from upstream

* Fri Nov 11 2022 happy_orange <songnannan@linux.alibaba.com>- 1.5.2-3
- add cmake files in devel package

* Wed Oct 19 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.5.2-2
- optimise spec file & add doc package

* Wed Mar 09 2022 zhang xianting <zhangxianting@uniontech.com> - 1.5.2-1
- Initial build for Anolis V23
